==> aliyun-python-sdk-dytnsapi-1.1.4.tar.gz: aliyun-python-sdk-dytnsapi-1.1.4/aliyunsdkdytnsapi/request/v20200217/DescribePhoneNumberAnalysisRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdytnsapi.endpoint import endpoint_data

class DescribePhoneNumberAnalysisRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Dytnsapi', '2020-02-17', 'DescribePhoneNumberAnalysis')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ResourceOwnerId(self): # Long
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
	def get_Rate(self): # Long
		return self.get_query_params().get('Rate')

	def set_Rate(self, Rate):  # Long
		self.add_query_param('Rate', Rate)
	def get_Mask(self): # String
		return self.get_query_params().get('Mask')

	def set_Mask(self, Mask):  # String
		self.add_query_param('Mask', Mask)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_NumberType(self): # Integer
		return self.get_query_params().get('NumberType')

	def set_NumberType(self, NumberType):  # Integer
		self.add_query_param('NumberType', NumberType)
	def get_AuthCode(self): # String
		return self.get_query_params().get('AuthCode')

	def set_AuthCode(self, AuthCode):  # String
		self.add_query_param('AuthCode', AuthCode)
	def get_InputNumber(self): # String
		return self.get_query_params().get('InputNumber')

	def set_InputNumber(self, InputNumber):  # String
		self.add_query_param('InputNumber', InputNumber)

==> aliyun-python-sdk-dytnsapi-1.1.8.tar.gz: aliyun-python-sdk-dytnsapi-1.1.8/aliyunsdkdytnsapi/request/v20200217/DescribePhoneNumberAnalysisRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdytnsapi.endpoint import endpoint_data

class DescribePhoneNumberAnalysisRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Dytnsapi', '2020-02-17', 'DescribePhoneNumberAnalysis')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ResourceOwnerId(self): # Long
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
	def get_Rate(self): # Long
		return self.get_query_params().get('Rate')

	def set_Rate(self, Rate):  # Long
		self.add_query_param('Rate', Rate)
	def get_Mask(self): # String
		return self.get_query_params().get('Mask')

	def set_Mask(self, Mask):  # String
		self.add_query_param('Mask', Mask)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_NumberType(self): # Long
		return self.get_query_params().get('NumberType')

	def set_NumberType(self, NumberType):  # Long
		self.add_query_param('NumberType', NumberType)
	def get_AuthCode(self): # String
		return self.get_query_params().get('AuthCode')

	def set_AuthCode(self, AuthCode):  # String
		self.add_query_param('AuthCode', AuthCode)
	def get_InputNumber(self): # String
		return self.get_query_params().get('InputNumber')

	def set_InputNumber(self, InputNumber):  # String
		self.add_query_param('InputNumber', InputNumber)
